<?php

namespace Drupal\edit_uuid\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'uuid' formatter.
 *
 * @FieldFormatter(
 *   id = "edit_uuid",
 *   label = @Translation("UUID"),
 *   field_types = {
 *     "uuid",
 *   },
 * )
 */
class EditUuidFieldFormatter extends FormatterBase {

  /**
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

/**
   * Constructor.
   *
   * @param \Drupal\Core\Session\AccountProxyInterface $currentUser
   * The current user.
   */
  public function __construct(AccountProxyInterface $currentUser) {
    $this->currentUser = $currentUser;
  }

 /**
   * {@inheritdoc}
   */
public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $user = $this->currentUser;
    if ($user->hasPermission('show edit_uuid')) {
      foreach ($items as $delta => $item) {
        $elements[$delta] = [
          '#markup' => $item->value,
        ];
      }
    }
    return $elements;
  }

}
